API
===

.. currentmodule:: pv_tandem

.. automodule:: pv_tandem.utils
   :members:
   :undoc-members:
   :show-inheritance:
   
.. automodule:: pv_tandem.solarcell_models
   :members:
   :undoc-members:
   :show-inheritance: